==> zio-aws-elasticinference_3-5.17.233.1-sources.jar: zio/aws/elasticinference/ElasticInferenceMock.scala <==
package zio.aws.elasticinference
import zio.aws.elasticinference.model.DescribeAcceleratorsResponse.ReadOnly
import zio.mock.{Proxy, Mock}
import zio.aws.core.AwsError
import software.amazon.awssdk.services.elasticinference.ElasticInferenceAsyncClient
import zio.aws.core.aspects.AwsCallAspect
import zio.aws.elasticinference.model.{
  ListTagsForResourceRequest,
  DescribeAcceleratorsRequest,
  DescribeAcceleratorOfferingsRequest,
  UntagResourceRequest,
  DescribeAcceleratorTypesRequest,
  TagResourceRequest
}
import zio.{IO, ZEnvironment, URLayer}
import zio.stream.ZStream
object ElasticInferenceMock extends Mock[ElasticInference] {
  object DescribeAcceleratorOfferings
      extends Effect[
        DescribeAcceleratorOfferingsRequest,
        AwsError,
        zio.aws.elasticinference.model.DescribeAcceleratorOfferingsResponse.ReadOnly
      ]
  object DescribeAccelerators
      extends Stream[
        DescribeAcceleratorsRequest,
        AwsError,
        zio.aws.elasticinference.model.ElasticInferenceAccelerator.ReadOnly
      ]
  object DescribeAcceleratorsPaginated
      extends Effect[DescribeAcceleratorsRequest, AwsError, ReadOnly]
  object UntagResource
      extends Effect[
        UntagResourceRequest,
        AwsError,
        zio.aws.elasticinference.model.UntagResourceResponse.ReadOnly
      ]
  object ListTagsForResource
      extends Effect[
        ListTagsForResourceRequest,
        AwsError,
        zio.aws.elasticinference.model.ListTagsForResourceResponse.ReadOnly
      ]
  object TagResource
      extends Effect[
        TagResourceRequest,
        AwsError,
        zio.aws.elasticinference.model.TagResourceResponse.ReadOnly
      ]
  object DescribeAcceleratorTypes
      extends Effect[
        DescribeAcceleratorTypesRequest,
        AwsError,
        zio.aws.elasticinference.model.DescribeAcceleratorTypesResponse.ReadOnly
      ]
  val compose: URLayer[Proxy, ElasticInference] = zio.ZLayer {
    zio.ZIO.service[Proxy].flatMap { proxy =>
      withRuntime[Proxy, ElasticInference] { rts =>
        zio.ZIO.succeed {
          new ElasticInference {
            val api: ElasticInferenceAsyncClient = null
            def withAspect[R1](
                newAspect: AwsCallAspect[R1],
                r: ZEnvironment[R1]
            ): ElasticInference = this
            def describeAcceleratorOfferings(
                request: DescribeAcceleratorOfferingsRequest
            ): IO[
              AwsError,
              zio.aws.elasticinference.model.DescribeAcceleratorOfferingsResponse.ReadOnly
            ] = proxy(DescribeAcceleratorOfferings, request)
            def describeAccelerators(
                request: DescribeAcceleratorsRequest
            ): ZStream[
              Any,
              AwsError,
              zio.aws.elasticinference.model.ElasticInferenceAccelerator.ReadOnly
            ] = zio.Unsafe.unsafeCompat { implicit u =>
              rts.unsafe
                .run {
                  proxy(DescribeAccelerators, request)
                }
                .getOrThrowFiberFailure()
            }
            def describeAcceleratorsPaginated(
                request: DescribeAcceleratorsRequest
            ): IO[AwsError, ReadOnly] =
              proxy(DescribeAcceleratorsPaginated, request)
            def untagResource(request: UntagResourceRequest): IO[
              AwsError,
              zio.aws.elasticinference.model.UntagResourceResponse.ReadOnly
            ] = proxy(UntagResource, request)
            def listTagsForResource(request: ListTagsForResourceRequest): IO[
              AwsError,
              zio.aws.elasticinference.model.ListTagsForResourceResponse.ReadOnly
            ] = proxy(ListTagsForResource, request)
            def tagResource(request: TagResourceRequest): IO[
              AwsError,
              zio.aws.elasticinference.model.TagResourceResponse.ReadOnly
            ] = proxy(TagResource, request)
            def describeAcceleratorTypes(
                request: DescribeAcceleratorTypesRequest
            ): IO[
              AwsError,
              zio.aws.elasticinference.model.DescribeAcceleratorTypesResponse.ReadOnly
            ] = proxy(DescribeAcceleratorTypes, request)
          }
        }
      }
    }
  }
}

==> zio-aws-elasticinference_3-5.19.7.3-sources.jar: zio/aws/elasticinference/ElasticInferenceMock.scala <==
package zio.aws.elasticinference
import zio.aws.elasticinference.model.DescribeAcceleratorsResponse.ReadOnly
import zio.mock.{Proxy, Mock}
import zio.aws.core.AwsError
import software.amazon.awssdk.services.elasticinference.ElasticInferenceAsyncClient
import zio.aws.core.aspects.AwsCallAspect
import zio.aws.elasticinference.model.{
  ListTagsForResourceRequest,
  DescribeAcceleratorsRequest,
  DescribeAcceleratorOfferingsRequest,
  UntagResourceRequest,
  DescribeAcceleratorTypesRequest,
  TagResourceRequest
}
import zio.{IO, ZEnvironment, URLayer}
import zio.stream.ZStream
object ElasticInferenceMock extends Mock[ElasticInference] {
  object DescribeAcceleratorOfferings
      extends Effect[
        DescribeAcceleratorOfferingsRequest,
        AwsError,
        zio.aws.elasticinference.model.DescribeAcceleratorOfferingsResponse.ReadOnly
      ]
  object DescribeAccelerators
      extends Stream[
        DescribeAcceleratorsRequest,
        AwsError,
        zio.aws.elasticinference.model.ElasticInferenceAccelerator.ReadOnly
      ]
  object DescribeAcceleratorsPaginated
      extends Effect[DescribeAcceleratorsRequest, AwsError, ReadOnly]
  object UntagResource
      extends Effect[
        UntagResourceRequest,
        AwsError,
        zio.aws.elasticinference.model.UntagResourceResponse.ReadOnly
      ]
  object ListTagsForResource
      extends Effect[
        ListTagsForResourceRequest,
        AwsError,
        zio.aws.elasticinference.model.ListTagsForResourceResponse.ReadOnly
      ]
  object TagResource
      extends Effect[
        TagResourceRequest,
        AwsError,
        zio.aws.elasticinference.model.TagResourceResponse.ReadOnly
      ]
  object DescribeAcceleratorTypes
      extends Effect[
        DescribeAcceleratorTypesRequest,
        AwsError,
        zio.aws.elasticinference.model.DescribeAcceleratorTypesResponse.ReadOnly
      ]
  val compose: URLayer[Proxy, ElasticInference] = zio.ZLayer {
    zio.ZIO.service[Proxy].flatMap { proxy =>
      withRuntime[Proxy, ElasticInference] { rts =>
        zio.ZIO.succeed {
          new ElasticInference {
            val api: ElasticInferenceAsyncClient = null
            def withAspect[R1](
                newAspect: AwsCallAspect[R1],
                r: ZEnvironment[R1]
            ): ElasticInference = this
            def describeAcceleratorOfferings(
                request: DescribeAcceleratorOfferingsRequest
            ): IO[
              AwsError,
              zio.aws.elasticinference.model.DescribeAcceleratorOfferingsResponse.ReadOnly
            ] = proxy(DescribeAcceleratorOfferings, request)
            def describeAccelerators(
                request: DescribeAcceleratorsRequest
            ): ZStream[
              Any,
              AwsError,
              zio.aws.elasticinference.model.ElasticInferenceAccelerator.ReadOnly
            ] = zio.Unsafe.unsafe { implicit u =>
              rts.unsafe
                .run {
                  proxy(DescribeAccelerators, request)
                }
                .getOrThrowFiberFailure()
            }
            def describeAcceleratorsPaginated(
                request: DescribeAcceleratorsRequest
            ): IO[AwsError, ReadOnly] =
              proxy(DescribeAcceleratorsPaginated, request)
            def untagResource(request: UntagResourceRequest): IO[
              AwsError,
              zio.aws.elasticinference.model.UntagResourceResponse.ReadOnly
            ] = proxy(UntagResource, request)
            def listTagsForResource(request: ListTagsForResourceRequest): IO[
              AwsError,
              zio.aws.elasticinference.model.ListTagsForResourceResponse.ReadOnly
            ] = proxy(ListTagsForResource, request)
            def tagResource(request: TagResourceRequest): IO[
              AwsError,
              zio.aws.elasticinference.model.TagResourceResponse.ReadOnly
            ] = proxy(TagResource, request)
            def describeAcceleratorTypes(
                request: DescribeAcceleratorTypesRequest
            ): IO[
              AwsError,
              zio.aws.elasticinference.model.DescribeAcceleratorTypesResponse.ReadOnly
            ] = proxy(DescribeAcceleratorTypes, request)
          }
        }
      }
    }
  }
}
